diff options
| author | Justin M. Keyes <justinkz@gmail.com> | 2026-06-13 01:40:05 +0200 |
|---|---|---|
| committer | Justin M. Keyes <justinkz@gmail.com> | 2026-06-13 20:54:00 +0200 |
| commit | 1d33a817517eb6cd3844b045def38eecb253f3c5 (patch) | |
| tree | fd56f0bfdb74a68390cee9918fa4c53124a23ec8 /test/functional/vimscript/executable_spec.lua | |
| parent | e36659c82f6d51631cf6a88a92ff2b467a078b18 (diff) | |
| download | rneovim-1d33a817517eb6cd3844b045def38eecb253f3c5.tar.gz rneovim-1d33a817517eb6cd3844b045def38eecb253f3c5.tar.bz2 rneovim-1d33a817517eb6cd3844b045def38eecb253f3c5.zip | |
test(autoread): cleanup
- Merged into the main "reloads on external change" test.
- Reduce duplication.
- Wall-clock down from ~4.4s to ~1.4s (dropped 3s debounce test).
Diffstat (limited to 'test/functional/vimscript/executable_spec.lua')
0 files changed, 0 insertions, 0 deletions